@@ -1,16 +1,23 @@
 import logging
 import typing
 
+from PySide2 import QtCore
+
 from famegui import models, colorpalette
+from famegui.scenario_graph_view_items import AgentGraphItem
 
 
-class AgentController(models.Agent):
+class AgentController(QtCore.QObject):
     """ Controller attached to a FAME Agent to sync it with the views """
 
+    model_was_modified = QtCore.Signal()
+
     def __init__(self, agent: models.Agent):
+        super().__init__()
+        assert agent is not None
         self.model = agent
+        self._scene_item = None
         self.tree_item = None
-        self.scene_item = None
 
     @property
     def id(self) -> int:
@@ -54,3 +61,19 @@ class AgentController(models.Agent):
     def y(self):
         assert self.model.display_xy is not None
         return self.model.display_xy[1]
+
+    @property
+    def scene_item(self) -> AgentGraphItem:
+        assert self._scene_item is not None
+        return self._scene_item
+
+    def set_scene_item(self, item: AgentGraphItem):
+        assert item.type() == AgentGraphItem.Type
+        assert self._scene_item is None  # should be attached to an item only once
+        self._scene_item = item
+        self._scene_item.position_changed = lambda x, y: self._item_position_changed(
+            x, y)
+
+    def _item_position_changed(self, x: int, y: int):
+        self.model.set_display_xy(x, y)
+        self.model_was_modified.emit()
