@@ -65,7 +65,7 @@ def _init_schemas_dir(work_dir: AppWorkingDir):
     # copy the default schema
     script_dir = os.path.dirname(os.path.abspath(__file__))
     default_schema_path = os.path.join(
-        script_dir, "data", "schema-AMIRIS-2020-10-23.yaml")
+        script_dir, "data", "schema-FAME-Demo-2021-04-13.yaml")
     logging.info("copying default schema file '{}' to {}".format(
         default_schema_path, schemas_dir))
     try:
@@ -85,7 +85,7 @@ def _init_scenarios_dir(work_dir: AppWorkingDir):
 
 
 def _init_timeseries_dir(work_dir: AppWorkingDir):
-    logging.debug("initializing simeseries dir")
+    logging.debug("initializing timeseries dir")
 
     timeseries_dir = work_dir.timeseries_dir
     if not os.path.isdir(timeseries_dir):
