@@ -10,7 +10,7 @@ def generate_protobuf_from_scenario_yaml_file(working_dir: str, input_path: str,
     assert os.path.isabs(output_path)
 
     try:
-        logging.info("changing current diretory to {}".format(working_dir))
+        logging.info("changing current directory to {}".format(working_dir))
         os.chdir(working_dir)
 
         config = {
@@ -25,6 +25,9 @@ def generate_protobuf_from_scenario_yaml_file(working_dir: str, input_path: str,
             "failed to generate the protobuf output, see the logs for more details")
 
 
+# review: Why do we have a cmd line interface for this part?
+#  Is this for convenience reasons during development or due to some subprocessing
+#  or Pyside interface requirement?
 def main():
     if len(sys.argv) != 2:
         print("Input scenario file must be passed in argument")
