@@ -9,10 +9,15 @@ class ScenarioGraphView(QtWidgets.QGraphicsScene):
 
     # (x, y)
     agent_creation_requested = QtCore.Signal(int, int)
+    # (agent_id)
+    agent_edition_requested = QtCore.Signal(int)
     # (sender_id, receiver_id)
     contract_creation_requested = QtCore.Signal(int, int)
     # agent_id (can be None)
     selected_agent_changed = QtCore.Signal(int)
+    # zoom factor control
+    zoom_in_requested = QtCore.Signal()
+    zoom_out_requested = QtCore.Signal()
 
     def __init__(self, parent=None):
         QtWidgets.QGraphicsScene.__init__(self, parent)
@@ -27,16 +32,15 @@ class ScenarioGraphView(QtWidgets.QGraphicsScene):
             return item.agent_id
         return None
 
-    def add_agent(self, agent: AgentController):
-        assert agent.scene_item is None
+    def add_agent(self, agent_ctrl: AgentController):
         # create item
         item = AgentGraphItem(
-            agent.id, agent.type_name, agent.svg_color)
-        item.setToolTip(agent.tooltip_text)
-        item.setPos(agent.x, agent.y)
+            agent_ctrl.id, agent_ctrl.type_name, agent_ctrl.svg_color)
+        item.setToolTip(agent_ctrl.tooltip_text)
+        item.setPos(agent_ctrl.x, agent_ctrl.y)
         # add item
         self.addItem(item)
-        agent.scene_item = item
+        agent_ctrl.set_scene_item(item)
 
     def add_contract(self, sender: AgentController, receiver: AgentController):
         self.addItem(ContractGraphItem(sender.scene_item, receiver.scene_item))
@@ -49,6 +53,7 @@ class ScenarioGraphView(QtWidgets.QGraphicsScene):
         # is the double click on an agent item?
         for item in self.items(click_pos):
             if item.type() == AgentGraphItem.Type:
+                self.agent_edition_requested.emit(item.agent_id)
                 return
 
         self.agent_creation_requested.emit(click_pos.x(), click_pos.y())
@@ -62,6 +67,15 @@ class ScenarioGraphView(QtWidgets.QGraphicsScene):
                     return
         QtWidgets.QGraphicsScene.mousePressEvent(self, event)
 
+    def wheelEvent(self, event):
+        # enable zoom in/out if ctrl key is pressed
+        if QtWidgets.QApplication.keyboardModifiers() == QtCore.Qt.ControlModifier:
+            if event.delta() > 0:
+                self.zoom_in_requested.emit()
+            else:
+                self.zoom_out_requested.emit()
+            event.accept()
+
     def _on_agent_right_clicked(self, agent_id):
         source_id = self.selected_agent_id
         if source_id is not None and source_id != agent_id:
