@@ -17,7 +17,7 @@ class UserSettings:
     def working_dir(self):
         dir_path = self._settings.value(self._KEY_WORKING_DIR)
         if dir_path is None:
-            logging.warn("path to working dir is not defined")
+            logging.warning("path to working dir is not defined")
         elif not os.path.isdir(dir_path):
             logging.warning(
                 "deleting invalid path to working dir: {}".format(dir_path))
